@@ -1,7 +1,7 @@
 package App::PDRUtils::DistIniCmd::sort_prereqs;
 
 our $DATE = '2016-03-03'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,6 +30,10 @@ Can detect one-spacing or two-spacing. Detects directives and comments.
 _
     args => {
         %App::PDRUtils::DistIniCmd::common_args,
+        spacing => {
+            summary => 'Set spacing explicitly',
+            schema => ['int*', min=>1, max=>10],
+        },
     },
 };
 sub handle_cmd {
@@ -81,7 +85,8 @@ sub handle_cmd {
                 parsed => $l,
             };
         }
-        my $spacing = floor(($num_blank_lines) / ($num_key_lines+1))+1;
+        my $spacing = $fargs{spacing} //
+            (floor(($num_blank_lines) / ($num_key_lines+1))+1);
 
         # there's no prereq lines, no need to sort this section
         next unless $num_key_lines;
@@ -123,7 +128,7 @@ sub handle_cmd {
                 my $lrec = $lines[$i];
                 if (!defined($cur_mod) || $cur_mod ne $lrec->{mod}) {
                     for (1..$spacing-1) {
-                        splice @lines, $i, 0, {parsed=>['B', "\n"]};
+                        splice @lines, $i+1, 0, {parsed=>['B', "\n"]};
                     }
                 }
                 $cur_mod = $lrec->{mod};
@@ -164,7 +169,7 @@ App::PDRUtils::DistIniCmd::sort_prereqs - Sort lines in `[Prereqs/*]` sections
 
 =head1 VERSION
 
-This document describes version 0.05 of App::PDRUtils::DistIniCmd::sort_prereqs (from Perl distribution App-PDRUtils), released on 2016-03-03.
+This document describes version 0.06 of App::PDRUtils::DistIniCmd::sort_prereqs (from Perl distribution App-PDRUtils), released on 2016-03-03.
 
 =head1 FUNCTIONS
 
@@ -188,6 +193,10 @@ Arguments ('*' denotes required arguments):
 
 =item * B<parsed_dist_ini>* => I<obj>
 
+=item * B<spacing> => I<int>
+
+Set spacing explicitly.
+
 =back
 
 Returns an enveloped result (an array).
